Skip to contents

A table containing the connection between the Thryve ID codes for activity types listed in the value column for variables ActivityTypeDetail1 and ActivityTypeDetail2.

Usage

activity_types

Format

activity_types

A data frame with 125 rows and 2 columns:

code

Thryve ID specifying a type of activity for ActivityTypeDetail1 and ActivityTypeDetail2

activity

The type of activity, e.g. "Walk", "Run, "Bike", etc.