Skip to contents

Clean mpathwear intraday (i.e. dynamic) data

Usage

clean_dynamic_data(data, .col = "dynamicData", connectionId = "connectionId")

Arguments

data

A data frame containing the wearable data, as returned by read_mpathwear().

.col

The column containing the data to be unpacked.

connectionId

The column containing the participant ID.

Value

A tibble containing at least the following columns:

connectionIdThe participant ID in m-Path, as specified by the connectionId argument.
start_timeThe start time of the measurement.
end_timeThe end time of the measurement.
categoryThe overall category of the measurement.
subcategoryThe more specific category of the measurement.
variableThe variable name of the measurement.
valueThe value of the measurement.
timezoneOffsetThe timezone offset of the measurement compared to UTC.
generationWhether the measurement was a calculation, automatic measurement, or manual input.
chronologicalExactnessThe imprecision of the timestamp in minutes. This imprecision occurs when some specific sources give the summary of activity without precise information about timestamp of specific activity.
created_atThe time the measurement was created or updated.
data_sourceThe data source of the measurement. Also see data_sources.
descriptionThe description of the measurement.
available_sourcesThe available data sources (e.g. Garmin, Fitbit) for this type of measurement.